/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgH

Description
    NSRDS function number 100

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgH_H
#define NSRDSfuncgH_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgH Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgH
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 100 coefficients
        scalar a_, b_, c_, d_, e_, f_;
        scalar h[51];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgH");


    // Constructors

        //- Construct from components
        NSRDSfuncgH(scalar a, scalar b, scalar c, scalar d, scalar e, scalar f)
        :
            a_(a),
            b_(b),
            c_(c),
            d_(d),
            e_(e),
            f_(f)
        {}

        //- Construct from Istream
        NSRDSfuncgH(Istream& is)
        :
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is)),
            e_(readScalar(is)),
            f_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgH() {
            h[0] = 0.00000e+00;
            h[1] = 9.52081e+04;
            h[2] = 1.90416e+05;
            h[3] = 3.36348e+05;
            h[4] = 5.25693e+05;
            h[5] = 7.58268e+05;
            h[6] = 1.02924e+06;
            h[7] = 1.33302e+06;
            h[8] = 1.66494e+06;
            h[9] = 2.01569e+06;
            h[10] = 2.38847e+06;
            h[11] = 2.77580e+06;
            h[12] = 3.17816e+06;
            h[13] = 3.59550e+06;
            h[14] = 4.01989e+06;
            h[15] = 4.45577e+06;
            h[16] = 4.89164e+06;
            h[17] = 5.32752e+06;
            h[18] = 5.76339e+06;
            h[19] = 6.19927e+06;
            h[20] = 6.63514e+06;
            h[21] = 7.07102e+06;
            h[22] = 7.50689e+06;
            h[23] = 7.94277e+06;
            h[24] = 8.37864e+06;
            h[25] = 8.81452e+06;
            h[26] = 9.25039e+06;
            h[27] = 9.68627e+06;
            h[28] = 1.01221e+07;
            h[29] = 1.05580e+07;
            h[30] = 1.09939e+07;
            h[31] = 1.14298e+07;
            h[32] = 1.18656e+07;
            h[33] = 1.23015e+07;
            h[34] = 1.27374e+07;
            h[35] = 1.31733e+07;
            h[36] = 1.36091e+07;
            h[37] = 1.40450e+07;
            h[38] = 1.44809e+07;
            h[39] = 1.49168e+07;
            h[40] = 1.53526e+07;
            h[41] = 1.57885e+07;
            h[42] = 1.62244e+07;
            h[43] = 1.66603e+07;
            h[44] = 1.70961e+07;
            h[45] = 1.75320e+07;
            h[46] = 1.79679e+07;
            h[47] = 1.84038e+07;
            h[48] = 1.88396e+07;
            h[49] = 1.92755e+07;
            h[50] = 1.97114e+07;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar h_ = 0.0;
      
	    for(int i=0; i<50; i++){
		   if(T>=100*i && T<100*(i+1)){
		   	h_ = h[i]+(T-100*i)*(h[i+1]-h[i])/100;
		   	break;
			}
		   }
	    return h_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_ << token::SPACE
                << e_ << token::SPACE
                << f_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgH& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
