/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgMu

Description
    NSRDS function number 101

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgMu_H
#define NSRDSfuncgMu_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgMu Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgMu
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 101 coefficients
        scalar a_, b_, c_, d_, e_;
        scalar mu[56];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgMu");


    // Constructors

        //- Construct from components
        NSRDSfuncgMu(scalar a, scalar b, scalar c, scalar d, scalar e)
        :
            a_(a),
            b_(b),
            c_(c),
            d_(d),
            e_(e)
        {}

        //- Construct from Istream
        NSRDSfuncgMu(Istream& is)
        :
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is)),
            e_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgMu() {
            mu[0] = 1.71000e-03;
            mu[1] = 1.71000e-03;
            mu[2] = 1.71000e-03;
            mu[3] = 1.71000e-03;
            mu[4] = 1.71000e-03;
            mu[5] = 1.71000e-03;
            mu[6] = 1.71000e-03;
            mu[7] = 1.71000e-03;
            mu[8] = 1.71000e-03;
            mu[9] = 1.71000e-03;
            mu[10] = 1.71000e-03;
            mu[11] = 1.71000e-03;
            mu[12] = 1.71000e-03;
            mu[13] = 1.71000e-03;
            mu[14] = 1.71000e-03;
            mu[15] = 1.71000e-03;
            mu[16] = 1.71000e-03;
            mu[17] = 1.71000e-03;
            mu[18] = 1.71000e-03;
            mu[19] = 1.71000e-03;
            mu[20] = 1.71000e-03;
            mu[21] = 1.71000e-03;
            mu[22] = 1.71000e-03;
            mu[23] = 1.48800e-03;
            mu[24] = 1.23900e-03;
            mu[25] = 1.04000e-03;
            mu[26] = 8.91200e-04;
            mu[27] = 7.69000e-04;
            mu[28] = 6.70700e-04;
            mu[29] = 5.64900e-04;
            mu[30] = 4.88600e-04;
            mu[31] = 4.29600e-04;
            mu[32] = 3.82600e-04;
            mu[33] = 3.41100e-04;
            mu[34] = 3.07800e-04;
            mu[35] = 2.78300e-04;
            mu[36] = 2.53900e-04;
            mu[37] = 2.31900e-04;
            mu[38] = 2.13400e-04;
            mu[39] = 1.96400e-04;
            mu[40] = 1.82100e-04;
            mu[41] = 1.69100e-04;
            mu[42] = 1.58500e-04;
            mu[43] = 1.49000e-04;
            mu[44] = 1.39200e-04;
            mu[45] = 1.29200e-04;
            mu[46] = 1.20900e-04;
            mu[47] = 1.13400e-04;
            mu[48] = 1.06900e-04;
            mu[49] = 1.00900e-04;
            mu[50] = 9.55800e-05;
            mu[51] = 9.05800e-05;
            mu[52] = 8.62600e-05;
            mu[53] = 8.22600e-05;
            mu[54] = 7.82600e-05;
            mu[55] = 7.42600e-05;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar mu_ = 0.0;
      
	    for(int i=0; i<55; i++){
		   if(T>=10*i && T<10*(i+1)){
		   	mu_ = mu[i]+(T-10*i)*(mu[i+1]-mu[i])/10;
		   	break;
			}
		   }
	    return mu_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_ << token::SPACE
                << e_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgMu& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
